==> multicontroller-0.0.1.tar.gz: test/multicontroller_test.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:multicontroller/multicontroller.dart';

String firstString(double val) => "first: $val";
String secondString(double val) => "second: $val";

void main() {
  testWidgets('Test MultiController within a widget', (WidgetTester tester) async {
    var widget = MultiControllerTestWidget();
    await tester.pumpWidget(widget);
    final first0 = find.text(firstString(0));
    expect(first0, findsOneWidget);
    final second0 = find.text(secondString(0));
    expect(second0, findsOneWidget);

    await tester.pumpAndSettle();

    final first1 = find.text(firstString(1));
    expect(first1, findsOneWidget);
    final second1 = find.text(secondString(1));
    expect(second1, findsOneWidget);
  });
}

class MultiControllerTestWidget extends StatefulWidget {
  @override
  _MultiControllerTestWidgetState createState() => _MultiControllerTestWidgetState();
}

class _MultiControllerTestWidgetState extends State<MultiControllerTestWidget> {
  Controller first;

  Controller second;

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: MultiController(
        initControllers: (createController, child) {
          first = createController(ControllerData(duration: Duration(milliseconds: 200)));
          second = createController(ControllerData(duration: Duration(milliseconds: 200)));
          first.chain(second);
          first.forward();
          return Column(
            children: <Widget>[
              AnimatedBuilder(
                animation: first,
                builder: (context, child) => Text(
                  firstString(first.value),
                  style: Theme.of(context).textTheme.headline1,
                ),
              ),
              AnimatedBuilder(
                animation: second,
                builder: (context, child) => Text(
                  secondString(second.value),
                  style: Theme.of(context).textTheme.headline1,
                ),
              ),
            ],
          );
        },
      ),
    );
  }
}

==> multicontroller-0.1.0.tar.gz: test/multicontroller_test.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:multicontroller/multicontroller.dart';

String firstString(double val) => "first: $val";
String secondString(double val) => "second: $val";

void main() {
  testWidgets('Test MultiController within a widget', (WidgetTester tester) async {
    var widget = MultiControllerTestWidget();
    await tester.pumpWidget(widget);
    final first0 = find.text(firstString(0));
    expect(first0, findsOneWidget);
    final second0 = find.text(secondString(0));
    expect(second0, findsOneWidget);

    await tester.pumpAndSettle();

    final first1 = find.text(firstString(1));
    expect(first1, findsOneWidget);
    final second1 = find.text(secondString(1));
    expect(second1, findsOneWidget);
  });
}

class MultiControllerTestWidget extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: MultiController(
        builder: (context, createController, child) {
          var first = createController(ControllerData(duration: Duration(milliseconds: 200)));
          var second = createController(ControllerData(duration: Duration(milliseconds: 200)));
          first.chain(second);
          first.forward();
          return Column(
            children: <Widget>[
              AnimatedBuilder(
                animation: first,
                builder: (context, child) => Text(
                  firstString(first.value),
                ),
              ),
              AnimatedBuilder(
                animation: second,
                builder: (context, child) => Text(
                  secondString(second.value),
                ),
              ),
            ],
          );
        },
      ),
    );
  }
}
